@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import PoolMeta
 
 __all__ = ['LandedCost']
 
@@ -21,25 +21,13 @@ class LandedCost:
 
     def _get_weight_factors(self):
         "Return the factor for each move based on weight"
-        pool = Pool()
-        ModelData = pool.get('ir.model.data')
-        Uom = pool.get('product.uom')
-
-        kg = Uom(ModelData.get_id('product', 'uom_kilogram'))
         moves = [m for s in self.shipments for m in s.incoming_moves
             if m.state != 'cancel']
 
         sum_weight = Decimal(0)
         weights = {}
         for move in moves:
-            if not move.product.weight:
-                weight = 0
-            else:
-                weight = Uom.compute_qty(
-                    move.product.weight_uom,
-                    move.product.weight * move.internal_quantity,
-                    kg, round=False)
-            weight = Decimal(str(weight))
+            weight = Decimal(str(move.internal_weight or 0))
             weights[move.id] = weight
             sum_weight += weight
         factors = {}
